@@ -15,20 +15,18 @@
 #
 import abc
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
-import pkg_resources
 
-import google.auth  # type: ignore
 import google.api_core
 from google.api_core import exceptions as core_exceptions
-from google.api_core import gapic_v1
+from google.api_core import gapic_v1, operations_v1
 from google.api_core import retry as retries
-from google.api_core import operations_v1
+import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
-from google.oauth2 import service_account  # type: ignore
-
-from google.cloud.managedidentities_v1.types import managed_identities_service
-from google.cloud.managedidentities_v1.types import resource
 from google.longrunning import operations_pb2  # type: ignore
+from google.oauth2 import service_account  # type: ignore
+import pkg_resources
+
+from google.cloud.managedidentities_v1.types import managed_identities_service, resource
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
@@ -83,6 +81,7 @@ class ManagedIdentitiesServiceTransport(abc.ABC):
             always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                 be used for service account credentials.
         """
+
         # Save the hostname. Default to port 443 (HTTPS) if none is specified.
         if ":" not in host:
             host += ":443"
@@ -134,37 +133,53 @@ class ManagedIdentitiesServiceTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.list_domains: gapic_v1.method.wrap_method(
-                self.list_domains, default_timeout=60.0, client_info=client_info,
+                self.list_domains,
+                default_timeout=60.0,
+                client_info=client_info,
             ),
             self.get_domain: gapic_v1.method.wrap_method(
-                self.get_domain, default_timeout=60.0, client_info=client_info,
+                self.get_domain,
+                default_timeout=60.0,
+                client_info=client_info,
             ),
             self.update_domain: gapic_v1.method.wrap_method(
-                self.update_domain, default_timeout=60.0, client_info=client_info,
+                self.update_domain,
+                default_timeout=60.0,
+                client_info=client_info,
             ),
             self.delete_domain: gapic_v1.method.wrap_method(
-                self.delete_domain, default_timeout=60.0, client_info=client_info,
+                self.delete_domain,
+                default_timeout=60.0,
+                client_info=client_info,
             ),
             self.attach_trust: gapic_v1.method.wrap_method(
-                self.attach_trust, default_timeout=60.0, client_info=client_info,
+                self.attach_trust,
+                default_timeout=60.0,
+                client_info=client_info,
             ),
             self.reconfigure_trust: gapic_v1.method.wrap_method(
-                self.reconfigure_trust, default_timeout=60.0, client_info=client_info,
+                self.reconfigure_trust,
+                default_timeout=60.0,
+                client_info=client_info,
             ),
             self.detach_trust: gapic_v1.method.wrap_method(
-                self.detach_trust, default_timeout=60.0, client_info=client_info,
+                self.detach_trust,
+                default_timeout=60.0,
+                client_info=client_info,
             ),
             self.validate_trust: gapic_v1.method.wrap_method(
-                self.validate_trust, default_timeout=60.0, client_info=client_info,
+                self.validate_trust,
+                default_timeout=60.0,
+                client_info=client_info,
             ),
         }
 
     def close(self):
         """Closes resources associated with the transport.
 
-       .. warning::
-            Only call this method if the transport is NOT shared
-            with other clients - this may cause errors in other clients!
+        .. warning::
+             Only call this method if the transport is NOT shared
+             with other clients - this may cause errors in other clients!
         """
         raise NotImplementedError()
 
@@ -269,5 +284,9 @@ class ManagedIdentitiesServiceTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def kind(self) -> str:
+        raise NotImplementedError()
+
 
 __all__ = ("ManagedIdentitiesServiceTransport",)
